/*
 * WizardActivity.java
 *
 * Copyright (C) 2009 Tim Marston <edam@waxworlds.org>
 *
 * This file is part of the Import Contacts program (hereafter referred
 * to as "this program"). For more information, see
 * http://www.waxworlds.org/edam/software/android/import-contacts
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.waxworlds.importcontacts;

import android.app.Activity;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;

public class WizardActivity extends Activity
{
	private int _nextState = 0;

	@Override
	protected void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);

		// set up next button
		Button next = (Button)findViewById( R.id.next );
		next.setOnClickListener( new View.OnClickListener() {
			public void onClick( View view ) {
				onNext();
			}
		} );

		// set up back button
		Button back = (Button)findViewById( R.id.back );
		back.setOnClickListener( new View.OnClickListener() {
			public void onClick( View view ) {
				setResult( RESULT_OK );
				finish();
			}
		} );

		// enable back button?
		Bundle extras = getIntent().getExtras();
		if( extras != null ) {
			Boolean backstate = extras.getBoolean( "backstate" );
			if( backstate != null )
				( (Button)findViewById( R.id.back ) ).setEnabled( true );
		}
	}

	protected void onNext()
	{
		switchToState( _nextState );
	}

	protected void setNextState( int nextState )
	{
		// set next state and enable button
		_nextState = nextState;
		( (Button)findViewById( R.id.next ) ).setEnabled( true );
	}

	private void switchToState( int newState )
	{
		if( newState != 0 )
		{
			// create result data bundle
			Bundle bundle = new Bundle();
			bundle.putInt( "nextstate", newState );

			// create response intent and finish
			Intent i = new Intent();
			i.putExtras( bundle );
			setResult( RESULT_OK, i );
			finish();
		}
	}

	public SharedPreferences getSharedPreferences()
	{
		return super.getSharedPreferences( "ImportContacts", 0 );
	}
}